@@ -47,7 +47,7 @@ void Playlist::on_treeWidget_itemClicked(QTreeWidgetItem *item, int column)
             playlistlist->removePlaylist(item->text(column));
 
         this->updateList();
-        mode == NORMAL;
+        mode = NORMAL;
        // this->hide();
     }
 }
